@@ -71,7 +71,7 @@ class Fftw(Fft):
         # TODO can these be replaced with the FFT ones?
         self.variables.join('FFTW_INC_DIR', 'FFT_INC_DIR')
         self.variables.join('FFTW_LIB_DIR', 'FFT_LIB_DIR')
-        if 'FFT_STATIC_LIBS' in self.variables:
-            self.variables.join('FFTW_STATIC_LIBS', 'FFT_STATIC_LIBS')
-        if 'FFT_STATIC_LIBS_MT' in self.variables:
-            self.variables.join('FFTW_STATIC_LIBS_MT', 'FFT_STATIC_LIBS_MT')
+
+        for key in ('SHARED_LIBS', 'SHARED_LIBS_MT', 'STATIC_LIBS', 'STATIC_LIBS_MT'):
+            if 'FFT_' + key in self.variables:
+                self.variables.join('FFTW_' + key, 'FFT_' + key)
