@@ -98,7 +98,7 @@ class IntelFFTW(Fftw):
 
         def fftw_lib_exists(libname):
             """Helper function to check whether FFTW library with specified name exists."""
-            return any([os.path.exists(os.path.join(d, "lib%s.a" % libname)) for d in fft_lib_dirs])
+            return any(os.path.exists(os.path.join(d, "lib%s.a" % libname)) for d in fft_lib_dirs)
 
         if not fftw_lib_exists(interface_lib) and LooseVersion(imklver) >= LooseVersion("10.2"):
             # interface libs can be optional:
@@ -112,14 +112,15 @@ class IntelFFTW(Fftw):
         # filter out libraries from list of FFTW libraries to check for if they are not provided by Intel MKL
         check_fftw_libs = [lib for lib in fftw_libs if lib not in ['dl', 'gfortran']]
 
-        if all([fftw_lib_exists(lib) for lib in check_fftw_libs]):
-            self.FFT_LIB = fftw_libs
-        else:
+        missing_fftw_libs = [lib for lib in check_fftw_libs if not fftw_lib_exists(lib)]
+        if missing_fftw_libs:
             msg = "Not all FFTW interface libraries %s are found in %s" % (check_fftw_libs, fft_lib_dirs)
-            msg += ", can't set $FFT_LIB."
+            msg += ", can't set $FFT_LIB. Missing: %s" % (missing_fftw_libs)
             if self.dry_run:
                 dry_run_warning(msg, silent=build_option('silent'))
             else:
                 raise EasyBuildError(msg)
+        else:
+            self.FFT_LIB = fftw_libs
 
         self.FFT_LIB_MT = fftw_mt_libs
